package vendoerivendo.persistence;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.Reader;
import java.util.ArrayList;
import java.util.List;
import java.util.NoSuchElementException;
import java.util.StringTokenizer;

import vendoerivendo.model.CategoriaMerceologica;
import vendoerivendo.model.Prodotto;

public class MyProdottiReader implements ProdottiReader {

	BufferedReader prodottiReader;

	public MyProdottiReader(Reader reader) throws IOException {
		prodottiReader = new BufferedReader(reader);
	}

	@Override
	public List<Prodotto> leggiProdotti() throws IOException, BadFileFormatException {
		List<Prodotto> listaprodotti = new ArrayList<>();

		try {
			String line;
			while ((line = prodottiReader.readLine()) != null) {
				StringTokenizer tokenizer = new StringTokenizer(line, "\t");
				
				String nome = tokenizer.nextToken().trim();
				
				double prezzo = Double.parseDouble(tokenizer.nextToken().trim());
				
				String descrizione = tokenizer.nextToken().trim();
				
				CategoriaMerceologica categoriaMerceologica = readCategoriaMerceologica(tokenizer);
				
				listaprodotti.add(new Prodotto(nome, descrizione, prezzo, categoriaMerceologica));
			}
		} catch (NoSuchElementException e) {
			throw new BadFileFormatException(e);
		} catch (NumberFormatException e) {
			throw new BadFileFormatException(e);
		}
		return listaprodotti;
	}

	private CategoriaMerceologica readCategoriaMerceologica(StringTokenizer tokenizer) throws BadFileFormatException {
		try {
		String token = tokenizer.nextToken().trim();
		return CategoriaMerceologica.valueOf(token);
		}
		catch (Exception e) {
			throw new BadFileFormatException("Categoria Merceologica", e);
		}
	}

}
